@@ -3,9 +3,16 @@ from django.conf.urls import url, patterns
 
 from modeltranslation.settings import AVAILABLE_LANGUAGES
 
-from .views import CategoryDetailView, PageDetailView
+from .views import CategoryDetailView, PageDetailView, SetLanguageView
 
-urlpatterns = list()
+
+urlpatterns = patterns('',
+
+    # Set language view
+    url(r'^i18n/td_cms_set_language/',
+        SetLanguageView.as_view(),
+        name='td_cms_set_language')
+)
 
 
 # Define all urls given available languages
@@ -22,7 +29,8 @@ for language_code in AVAILABLE_LANGUAGES:
             name='category_detail_%s' % language_code),
 
         # Page
-        url(base_url + r'(?P<category_slug>[-\w]+)/(?P<slug_%s>[-\w]+)/$' % (
+        url(
+            base_url + r'(?P<category_slug>[-\w]+)/(?P<slug_%s>[-\w]+)/$' % (
                 language_code
             ),
             PageDetailView.as_view(),
